package com.uavps.system.mapper;

import com.uavps.system.domain.UavpsAlgorithmTask;

import java.util.List;

/**
 * 算法任务Mapper接口
 *
 * @author ruoyi
 * @date 2025-02-18
 */
public interface UavpsAlgorithmTaskMapper {
    /**
     * 查询算法任务
     *
     * @param id 算法任务主键
     * @return 算法任务
     */
    public UavpsAlgorithmTask selectUavpsAlgorithmTaskById(Long id);

    /**
     * 查询算法任务列表
     *
     * @param uavpsAlgorithmTask 算法任务
     * @return 算法任务集合
     */
    public List<UavpsAlgorithmTask> selectUavpsAlgorithmTaskList(UavpsAlgorithmTask uavpsAlgorithmTask);

    /**
     * 新增算法任务
     *
     * @param uavpsAlgorithmTask 算法任务
     * @return 结果
     */
    public int insertUavpsAlgorithmTask(UavpsAlgorithmTask uavpsAlgorithmTask);

    /**
     * 修改算法任务
     *
     * @param uavpsAlgorithmTask 算法任务
     * @return 结果
     */
    public int updateUavpsAlgorithmTask(UavpsAlgorithmTask uavpsAlgorithmTask);

    /**
     * 删除算法任务
     *
     * @param id 算法任务主键
     * @return 结果
     */
    public int deleteUavpsAlgorithmTaskById(Long id);

    /**
     * 批量删除算法任务
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteUavpsAlgorithmTaskByIds(Long[] ids);
}
